#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-HxjiVViBX2Z29pMLV8SN4r
key:                  yesod-persistent-1.6.0.8-HxjiVViBX2Z29pMLV8SN4r
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  a06ecb72e46acb0db57ac199dd134886
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-persistent-1.6.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-HxjiVViBX2Z29pMLV8SN4r
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-4JIC4S953rP8VbASrBgFEC
    conduit-1.3.6.1-FIwCK0b1Hr15S6D1xh1znT
    persistent-2.14.6.0-3zzTRZmUktpL8M7RnGGvYV
    resource-pool-0.3.0.0-62Dm0NVblZD7NWlhkULWVR
    resourcet-1.3.0-Cuj4zJihfYr1ci2ntaM4ld transformers-0.6.1.0
    yesod-core-1.6.28.0-4V8vIWIpjE7J4FfIyyg0sQ

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

